---
jupytext:
  text_representation:
    format_name: myst
kernelspec:
  display_name: Python 3
  name: python3
---


# Try executing code cells in markdown

This is a `.md` file that has a special header and a `{code-cell}`
directive, that lets it

```{code-cell}
!hostname
```

You can see how this works [on the myst-nb
docs](https://myst-nb.readthedocs.io/en/latest/use/markdown.html).
